@@ -8,11 +8,14 @@ from django.conf import settings
 logger1 = logging.getLogger(__name__)
 
 
-def dictinct_list(l):
+def dictinct_list(l, _sorted=False, key=None):
     ds = []
     for item in l:
         if not item in ds:
             ds.append(item)
+
+    if _sorted:
+        return sorted(ds, key=lambda x: x[key])
     return ds
 
 
@@ -180,6 +183,9 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
 
 class Stack:
 
+    def __iter__(self):
+        return self.stack.__iter__()
+
     def __init__(self, stack=[]):
         self.stack = stack.copy()
 
@@ -208,7 +214,6 @@ class Stack:
             if isinstance(logger, Logger):
                 logger.debug(f'self.stack.append: {item}')
 
-
         if isinstance(logger, Logger):
             logger.debug(f'size stack: {len(self.stack)}')
         return True
