@@ -1,6 +1,7 @@
 import json
 import logging
 
+from isc_common import setAttr
 from isc_common.http.RPCRequest import RPCRequest
 
 logger = logging.getLogger(__name__)
@@ -96,6 +97,10 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def set_data(self, data):
+        if isinstance(data, dict):
+            setAttr(self.json, 'data', data)
+
     def get_criteria(self, excluded_keys=['grid']):
         data = self.get_data(excluded_keys=excluded_keys)
         criteria = data.get('criteria')
